@@ -23,14 +23,3 @@ import Data.Primitive.Types
 import Data.Primitive.Array
 import Data.Primitive.ByteArray
 import Data.Primitive.Addr
-
-import GHC.Base ( Int(..) )
-
--- | Size of values of type @a@. The argument is not used.
-sizeOf :: Prim a => a -> Int
-sizeOf x = I# (sizeOf# x)
-
--- | Alignment of values of type @a@. The argument is not used.
-alignment :: Prim a => a -> Int
-alignment x = I# (alignment# x)
-
